==> nextcloud-18.0.6.tgz: nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Someone" : "Irgendjemand",
    "%s created %s" : "%s hat %s erstellt",
    "%s modified %s" : "%shat %s geändert",
    "%s deleted %s" : "%s hat  %s gelöscht",
    "%s accessed %s" : "%s hat auf %s zugegriffen",
    "%s renamed %s" : "%shat %s umbenannt",
    "%s copied %s" : "%s hat %s kopiert",
    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Kein Ereignis ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
    "Invalid check provided" : "Ungültiger Test bereitgestellt",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Flow" : "Ablauf",
    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter wählen",
    "Select a comparator" : "Wählen Sie einen Komparator",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Folder" : "Ordner",
    "Images" : "Bilder",
    "Office documents" : "Office Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
    "Select a tag" : "Schlagwort auswählen",
    "No results" : "Keine Ergebnisse",
    "%s (invisible)" : "%s (unsichtbar)",
    "%s (restricted)" : "%s (eingeschränkt)",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Others" : "Andere",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a user agent" : "User-Agenten wählen",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "At least one event must be selected" : "Mindestens ein Termin muss ausgewählt werden",
    "Add new flow" : "Neuen Ablauf hinzufügen",
    "When" : "Wenn",
    "and" : "und",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Active" : "Aktiv",
    "Save" : "Speichern",
    "Available flows" : "Verfügbare Abläufe",
    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, finden Sie in der Entwickler-Dokumentation.",
    "More flows" : "Weitere Abläufe",
    "Browse the app store" : "Appstore durchsuchen",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "Configured flows" : "Konfigurierte Abläufe",
    "Your flows" : "Ihre Abläufe",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "is" : "ist",
    "is not" : "ist nicht",
    "File name" : "Dateiname",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaborativer Tag an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "Select tag…" : "Wählen Sie ein Tag…",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wählen Sie die Zeitzone…",
    "Sync clients" : "Sync-Clients",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "Tag management" : "Schlagwortverwaltung",
    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.10.tgz: nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Someone" : "Irgendjemand",
    "%s created %s" : "%s hat %s erstellt",
    "%s modified %s" : "%shat %s geändert",
    "%s deleted %s" : "%s hat  %s gelöscht",
    "%s accessed %s" : "%s hat auf %s zugegriffen",
    "%s renamed %s" : "%shat %s umbenannt",
    "%s copied %s" : "%s hat %s kopiert",
    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Keine Ereignisse ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
    "The provided operation data is too long" : "Die bereitgestellten Betriebsdaten sind zu lang",
    "Invalid check provided" : "Ungültiger Test bereitgestellt",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "The provided check value is too long" : "Der bereitgestellte Prüfwert ist zu lang",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Flow" : "Ablauf",
    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter wählen",
    "Select a comparator" : "Wählen Sie einen Komparator",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Folder" : "Ordner",
    "Images" : "Bilder",
    "Office documents" : "Office Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
    "Select a tag" : "Schlagwort auswählen",
    "No results" : "Keine Ergebnisse",
    "%s (invisible)" : "%s (unsichtbar)",
    "%s (restricted)" : "%s (eingeschränkt)",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Others" : "Andere",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a user agent" : "User-Agenten wählen",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook Addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "At least one event must be selected" : "Mindestens ein Termin muss ausgewählt werden",
    "Add new flow" : "Neuen Ablauf hinzufügen",
    "When" : "Wenn",
    "and" : "und",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Active" : "Aktiv",
    "Save" : "Speichern",
    "Available flows" : "Verfügbare Abläufe",
    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, finden Sie in der Entwickler-Dokumentation.",
    "More flows" : "Weitere Abläufe",
    "Browse the app store" : "Appstore durchsuchen",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "Configured flows" : "Konfigurierte Abläufe",
    "Your flows" : "Ihre Abläufe",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "is" : "ist",
    "is not" : "ist nicht",
    "File name" : "Dateiname",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaborativer Tag an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von"
},
"nplurals=2; plural=(n != 1);");
